/*
    SPDX-FileCopyrightText: 2023 Friedrich W. H. Kossebau <kossebau@kde.org>

    SPDX-License-Identifier: LGPL-2.1-or-later
*/

#include <ki18n_export.h>

#if KI18N_ENABLE_DEPRECATED_SINCE(5, 105)
#include <kuitsetup.h>
#if KI18N_DEPRECATED_WARNINGS_SINCE >= 0x056900
#pragma message("Deprecated header. Since 5.0, use #include <kuitsetup.h> instead")
#endif
#else
#error "Include of deprecated header is disabled"
#endif
